Anipose visualization

×

# Visualization and Editing

# Visualization and Temporal labels

### Videos

Command | Action
--- | ---
Play/Pause media | 'play'
Increase/Decrease media playback speed | 'speed up' / 'slow down'
Load the previous/next video | 'previous' / 'next'
Toggle 2d tracking | 'hide 2d' / 'display 2d'

### 3D model

Command | Action
--- | ---
Rotate model | click+drag
Translate model | ctrl+click+drag
Zoom in/out on model | scroll up / scroll down

### Temporal labels

Command | Action
--- | ---
Select a temporal segment | click

# Keyboard Shortcuts

### General

Command | Shortcut
--- | ---
Play/Pause media | Space
Increase/Decrease media playback speed | + / -
Advance one frame | .
Go back one frame | ,

### When a Temporal Segment is Selected

Command | Shortcut
--- | ---
Play/Pause video locked to segment boundary | Space
Unselect temporal segment | Esc

×

# Visualization and Temporal labels

### Videos

Command | Action
--- | ---
Play/Pause media | 'play'
Increase/Decrease media playback speed | 'speed up' / 'slow down'
Load the previous/next video | 'previous' / 'next'
Toggle 2d tracking | 'hide 2d' / 'display 2d'

### 3D model

Command | Action
--- | ---
Rotate model | click+drag
Translate model | ctrl+click+drag
Zoom in/out on model | scroll up / scroll down

### Temporal labels

Command | Action
--- | ---
Select a temporal segment | click
Add a temporal segment | double click
Translate a temporal segment | click+drag
Resize a temporal segment | click+drag edge
Add a new behavior | 'add behavior'
Remove behaviors with no temporal segments | 'clear unused behaviors'
Save behavior edits | 'push changes'

# Keyboard Shortcuts

### General

Command | Shortcut
--- | ---
Play/Pause media | Space
Increase/Decrease media playback speed | + / -
Advance one frame | .
Go back one frame | ,

### When a Temporal Segment is Selected

Command | Shortcut
--- | ---
Play/Pause video locked to segment boundary | Space
Delete selected temporal segment | Backspace
Unselect temporal segment | Esc
Expand/Contract the left edge by one frame | Shift + ← / →
Expand/Contract the right edge by one frame | Ctrl + ← / →
Translate selected temporal segment to the left/right | ← / →
Shift up/down one behavior | ↑ / ↓
Label temporal segment as automatic/manual | Enter

slowed 10x
0 / 0 00:00:00 / 00:00:00
0